@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012 Vincent Jacques
-# vincent@vincent-jacques.net
+# Copyright 2012 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2012 Zearin zearin@gonk.net
+# Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -20,7 +21,7 @@ import GithubException
 
 class _NotSetType:
     def __repr__(self):
-        return "NotSet"  # pragma no cover
+        return "NotSet"
 NotSet = _NotSetType()
 
 
