@@ -2,6 +2,7 @@
 
 # Copyright 2013 Peter Golm golm.peter@gmail.com
 # Copyright 2013 Vincent Jacques vincent@vincent-jacques.net
+# Copyright 2013 martinqt m.ki2@laposte.net
 
 # This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
@@ -21,7 +22,7 @@ import github.NotificationSubject
 
 class Notification(github.GithubObject.CompletableGithubObject):
     """
-    This class represents Notifications as returned for example by http://developer.github.com/v3/activity/notifications/#list-your-notifications
+    This class represents Notifications. The reference can be found here http://developer.github.com/v3/activity/notifications/
     """
 
     @property
