@@ -15,6 +15,7 @@
 # You should have received a copy of the GNU Lesser General Public License along with PyGithub.  If not, see <http://www.gnu.org/licenses/>.
 
 import Framework
+from github.PaginatedList import PaginatedList as PaginatedListImpl
 
 
 class PaginatedList(Framework.TestCase):
@@ -89,6 +90,23 @@ class PaginatedList(Framework.TestCase):
         self.assertEqual(self.g.per_page, 100)
         self.assertEqual(len(list(self.repo.get_issues())), 456)
 
+    def testCustomPerPageWithNoUrlParams(self):
+        import CommitComment  # Don't polute github.tests namespace, it would conflict with github.tests.CommitComment
+        self.g.per_page = 100
+        paginated_list = PaginatedListImpl(
+            CommitComment.CommitComment,
+            self.repo._requester,
+            self.repo.url + "/comments",
+            None
+        )
+
+    def testCustomPerPageWithNoUrlParams2(self):
+        # This test is redountant and less unitary than testCustomPerPageWithNoUrlParams
+        # but I hope it will be more robust if we refactor PaginatedList,
+        # because testCustomPerPageWithNoUrlParams only tests the constructor
+        self.g.per_page = 100
+        self.assertEqual(len(list(self.repo.get_comments())), 325)
+
     def testCustomPerPageWithGetPage(self):
         self.g.per_page = 100
         self.assertEqual(len(self.repo.get_issues().get_page(2)), 100)
